==> openwebbeans-1.2.8-source-release.zip: openwebbeans-1.2.8/webbeans-impl/src/test/java/org/apache/webbeans/test/component/disposal/Disposal1.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component.disposal;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.enterprise.context.RequestScoped;
import javax.enterprise.context.SessionScoped;
import javax.enterprise.inject.Disposes;
import javax.enterprise.inject.Produces;
import javax.inject.Named;

import org.apache.webbeans.test.annotation.binding.Binding1;


@SessionScoped
public class Disposal1 implements Serializable
{
    static boolean disposeCall = false;

    public Disposal1()
    {

    }
    
    public static boolean getDISPOSCALL()
    {
        return disposeCall;
    }

    @Produces
    @Binding1
    @Named
    @RequestScoped
    public List<Integer> createBinding1()
    {
        List<Integer> lst = new ArrayList<Integer>();
        lst.add(new Integer(42));
        return lst;
    }

    public void dispose(@Disposes @Binding1 List<Integer> list)
    {
        disposeCall = true;
        list.clear();
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/component/disposal/Disposal1.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component.disposal;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import jakarta.enterprise.context.RequestScoped;
import jakarta.enterprise.context.SessionScoped;
import jakarta.enterprise.inject.Disposes;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Named;

import org.apache.webbeans.test.annotation.binding.Binding1;


@SessionScoped
public class Disposal1 implements Serializable
{
    static boolean disposeCall = false;

    public Disposal1()
    {

    }
    
    public static boolean getDISPOSCALL()
    {
        return disposeCall;
    }

    @Produces
    @Binding1
    @Named
    @RequestScoped
    public List<Integer> createBinding1()
    {
        List<Integer> lst = new ArrayList<Integer>();
        lst.add(new Integer(42));
        return lst;
    }

    public void dispose(@Disposes @Binding1 List<Integer> list)
    {
        disposeCall = true;
        list.clear();
    }
}
